===============
API Reference
===============

.. currentmodule:: mobility_report

DpMobilityReport
~~~~~~~~~~~~~~~~~~~
.. autoclass:: dp_mobility_report.dpmreport.DpMobilityReport
	:members: report, to_file, tessellation, df, privacy_budget, max_trips_per_user, analysis_exclusion, budget_split

BenchmarkReport
~~~~~~~~~~~~~~~~~~~
.. autoclass:: dp_mobility_report.benchmark.benchmarkreport.BenchmarkReport
	:members: smape, jsd, kld, emd, similarity_measures, report_base, report_alternative, measure_selection
	